@@ -90,7 +90,7 @@ def run(
         tags: list = [],
         load_override: Union[dict, None] = None
 ):
-    queue, _ = start_render_queue()
+    queue, render_thread = start_render_queue()
 
     if address:  # pragma: no cover
         logging.info('Bind address: %s', address)
@@ -111,8 +111,22 @@ def run(
         logging.exception('Mock server loading error:')
         with _nostderr():
             raise
+
+    prev_handler = signal.getsignal(signal.SIGHUP)
+    do_restart = [False]  # mutable
+
+    def sighup_handler(num, frame):
+        logging.info("Received SIGHUP")
+        http_server.stop()
+        render_thread.kill()
+        signal.signal(signal.SIGHUP, prev_handler)
+        do_restart[0] = True
+
+    signal.signal(signal.SIGHUP, sighup_handler)
     http_server.run()
 
+    return do_restart[0]
+
 
 def _gracefully_exit(num, frame):
     atexit._run_exitfuncs()
@@ -271,15 +285,9 @@ def initiate(argv=None):
         logging.info("%s v%s is starting...", PROGRAM.capitalize(), __version__)
 
         if not cov_no_run:  # pragma: no cover
-            run(
-                source,
-                debug=debug_mode,
-                interceptors=interceptors,
-                address=address,
-                services_list=services_list,
-                tags=tags,
-                load_override=load_override
-            )
+            while run(source, debug=debug_mode, interceptors=interceptors, address=address,
+                      services_list=services_list, tags=tags, load_override=load_override):
+                logging.info("Restarting...")
 
 
 def demo_run():
